from abc import ABC, abstractmethod


class SettingsInterface(ABC):
    # web console url
    WEB_URL: str
    # table name
    KNOWLEDGE_TABLE_NAME: str
    CHUNK_TABLE_NAME: str
    TASK_TABLE_NAME: str
    ACTION_TABLE_NAME: str
    TENANT_TABLE_NAME: str
    # log dir
    LOG_DIR: str
    # plugin env
    PLUGIN_ENV = dict

    @abstractmethod
    def load_plugin_dir_env(self, plugin_env_path: str) -> dict:
        pass

    @abstractmethod
    def get_env(self, name: str, defaultValue: str) -> None:
        pass



from typing import Dict, List

from whiskerrag_types.interface.retriever_interface import BaseRetriever
from whiskerrag_types.model.retrieval import RetrievalChunk, RetrievalEnum
from whiskerrag_utils.registry import RegisterTypeEnum, register


@register(RegisterTypeEnum.RETRIEVER, RetrievalEnum.SIMILARITY)
class SimpleRetriever(BaseRetriever):
    chunk_list: List[RetrievalChunk]
    chunk_index: Dict[str, RetrievalChunk]
    doc_index: Dict[str, RetrievalChunk]

    def __init__(self, chunk_list: List[RetrievalChunk]):
        self.chunk_list = chunk_list
        self.chunk_index = self._build_index()

    def _build_index(self) -> Dict[str, RetrievalChunk]:
        return {
            chunk.chunk_id: chunk
            for chunk in self.chunk_list
            if chunk.chunk_id is not None
        }



from abc import ABC, abstractmethod
from typing import List

from langchain_core.documents import Document


class BaseLoader(ABC):
    @abstractmethod
    async def load(self) -> List[Document]:
        pass
